angular.module('camotion')
    .controller('SensorsController', ['$scope', 'SensorsService', '$timeout', 'luticateDialogErrorHelper',
        function($scope, SensorsService, $timeout, luticateDialogErrorHelper) {

            $scope.values = {};
            $scope.interval = 1000;

            $scope.luTable = {
                columns: [
                    {
                        name: "Name",
                        width: 3,
                        getValue: function (item) {
                            return item.Name;
                        }
                    },{
                        name: "Description",
                        width: 7,
                        getValue: function (item) {
                            return item.Description;
                        }
                    },{
                        name: "Value",
                        width: 2,
                        getValue: function (item) {
                            var value = $scope.values[item.Id];
                            return value.error == null ? value.value.Value : 'Error';
                        }
                    }
                ],

                getLoadPagePromise: function (page, perPage, query, promise) {
                    return SensorsService.getAll({page: page, perPage: perPage, query: query}, promise);
                },

                onPageChanged: function()
                {
                    for (var i in $scope.values) {
                        $timeout.cancel($scope.values[i].timerId);
                    }
                    $scope.values = {};
                    var items = $scope.luTable.luBasicTableScope.items.Data;
                    for (i = 0; i < items.length; ++i) {
                        var item = angular.copy(items[i]);
                        $scope.values[item.Id] = {
                            value: 0,
                            timerId: 0,
                            error: null
                        };
                        $scope.updateSensor(item);
                    }
                },

                canClick: function(sensor)
                {
                    var value = $scope.values[sensor.Id];
                    return value.error != null;
                },

                onItemClicked: function(sensor)
                {
                    var value = $scope.values[sensor.Id];
                    if (value.error != null) {
                        luticateDialogErrorHelper.errorDialog(value.error);
                    }
                }
            };

            $scope.updateSensor = function(sensor)
            {
                if (typeof $scope.values[sensor.Id] != 'undefined') {
                    SensorsService.getValue({sensor_id: sensor.Id})
                        .then(function (value) {
                            if (typeof $scope.values[sensor.Id] != 'undefined') {
                                $scope.values[sensor.Id] = {
                                    value: value,
                                    timerId: $timeout(function () {
                                        $scope.updateSensor(sensor);
                                    }, $scope.interval)
                                }
                            }
                        }, function(error)
                        {
                            if (typeof $scope.values[sensor.Id] != 'undefined') {
                                $scope.values[sensor.Id] = {
                                    value: 0,
                                    timerId: 0,
                                    error: error
                                }
                            }
                        });
                }
            };

            $scope.$on('$destroy', function() {
                $scope.values = {};
            });
    }]);
